==> firewire-angular-auth-1.0.1.tgz: package/index.js <==
var firewireAuthModule = angular.module('firewireAuthModule', [
	"firewireModule",
	"firebase"
]);

/*
	To enable anonymous login, user the following line within a controller
		$rootScope.fwUser('login', 'anom');
*/

firewireAuthModule.run(function($firebaseAuth, fbref, $rootScope, fwUser, realtimeFw) {
    $rootScope.auth = $firebaseAuth(fbref);
    $rootScope.auth.loginStatus = 'loggedOut';
    $rootScope.auth.$onAuth(function(authdata){
    	$rootScope.auth.authdata = authdata;
    	if(!authdata){
    		$rootScope.user = {};
    		$rootScope.auth.loginStatus = 'loggedOut';
    	}
    	else {
    		$rootScope.user = fwUser.get(authdata);
    		$rootScope.auth.loginStatus = 'loggedIn';
    		$rootScope.nofw = realtimeFw.get(fw.map);
    	}
    });

    $rootScope.fwUser = function(action, provider, id, password){
		console.log(fwUser.act(action, provider, id, password));
	};
});

firewireAuthModule.factory('fwUser',['$rootScope', '$firebaseObject', 'fbref', function($rootScope, $firebaseObject, fbref){
	return {
		act : function(action, provider, id, password, changeParameter){
			if(action === 'login'){
				$rootScope.auth.loginStatus = "trying";
				switch(provider) {
				    case 'password': passwordLogin(id, password); return action + " - called";
				        break;
				    case 'thirdParty':
				    	thirdPartyLogin(id); return action + " - called";
				    	break;
				    case 'anom':
				    	anomymousLogin(); return action + " - called";
				    	break;
				    default:
				        return action + " - failed";
				} 
			}
			// logout
			else if(action === 'logout'){
				$rootScope.auth.$unauth();
				return action + " - called";
			}
			// Change password
			else if(action === 'changePassword' && provider ==='password'){
				$rootScope.auth.$changePassword({
				  email: id,
				  oldPassword: password,
				  newPassword: changeParameter
				}).then(function() {
				  console.log("Password changed successfully!");
				}).catch(function(error) {
				  console.error("Error: ", error);
				});
			}
			// Change email
			else if(action ==='changeEmail' && provider ==='password'){
				$rootScope.auth.$changeEmail({
				  oldEmail: id,
				  newEmail: changeParamer,
				  password: password
				}).then(function() {
				  console.log("Email changed successfully!");
				}).catch(function(error) {
				  console.error("Error: ", error);
				});
			}

			// third party login function
			function thirdPartyLogin(id){
				$rootScope.auth.$authWithOAuthPopup(id).then(function(authData) {
				  console.log("Logged in");
				  $rootScope.auth.alertMsg = '';
				  $rootScope.auth.alert = '';
				}).catch(function(error) {
				  console.error("Authentication failed:", error);
				  $rootScope.auth.loginStatus = 'loggedOut';
				  $rootScope.auth.alert = 'autherror';
				  $rootScope.auth.alertMsg = error.message;
				  $rootScope.auth.alertMsg = "Error logging user in";
				});
			};

			// password login function
			function passwordLogin(email, password){
				$rootScope.auth.$authWithPassword({
				  email: id,
				  password: password
				}).then(function(authData) {
				  console.log("Logged in");
				  $rootScope.auth.alertMsg = '';
				  $rootScope.auth.alert = '';
				}).catch(function(error) {
				  //console.error("Authentication failed:", error);
				  $rootScope.auth.loginStatus = 'loggedOut';
				  $rootScope.auth.alert = 'autherror';
				  if (error) {
				    switch (error.code) {
				      case "INVALID_EMAIL":
				        $rootScope.auth.alertMsg = "The specified user account email is invalid.";
				        break;
				      case "INVALID_PASSWORD":
				        $rootScope.auth.alertMsg = "The specified user account password is incorrect.";
				        break;
				      case "INVALID_USER":
				        $rootScope.auth.alertMsg = "The specified user account does not exist.";
				        $rootScope.auth.alertType = "danger";
				        break;
				      default:
				        $rootScope.auth.alertMsg = "Error logging user in:";
				    };
				  }
				});
			};

			// anonymous login
			function anomymousLogin(){
				$rootScope.auth.$authAnonymously().then(function(authData) {
				  console.log("Logged in anonymously");
				  $rootScope.auth.alertMsg = '';
				  $rootScope.auth.alert = '';
				}).catch(function(error) {
				  console.error("Authentication failed:", error);
				  $rootScope.auth.loginStatus = 'loggedOut';
				  $rootScope.auth.alert = 'autherror';
				  $rootScope.auth.alertMsg = "Error logging user in";
				});
			}
		},
		get : function(authdata){
			return $firebaseObject(fbref.child('users/' + authdata.uid));
		}
	}
}]);

==> firewire-angular-auth-1.0.5.tgz: package/index.js <==
var firewireAuthModule = angular.module('firewireAuthModule', [
	"firewireModule",
	"firebase"
]);

/*
	To enable anonymous login, user the following line within a controller
		$rootScope.fwUser('login', 'anom');
*/

firewireAuthModule.run(function($firebaseAuth, fbref, $rootScope, fwUser, realtimeFw) {
    $rootScope.auth = $firebaseAuth(fbref);
    $rootScope.auth.loginStatus = 'loggedOut';
    $rootScope.auth.$onAuth(function(authdata){
    	$rootScope.auth.authdata = authdata;
    	if(!authdata){
    		$rootScope.user = {};
    		$rootScope.auth.loginStatus = 'loggedOut';
    	}
    	else {
    		$rootScope.user = fwUser.get(authdata);
    		$rootScope.auth.loginStatus = 'loggedIn';
    		$rootScope.nofw = realtimeFw.get(fw.map);
    	}
    });

    $rootScope.fwUser ={};
    $rootScope.fwUser.act = function(action, provider, id, password){
		console.log(fwUser.act(action, provider, id, password));
	};
});

firewireAuthModule.factory('fwUser',['$rootScope', '$firebaseObject', 'fbref', function($rootScope, $firebaseObject, fbref){
	return {
		act : function(action, provider, id, password, changeParameter){
			if(action === 'login'){
				$rootScope.auth.loginStatus = "trying";
				switch(provider) {
				    case 'password': passwordLogin(id, password); return action + " - called";
				        break;
				    case 'thirdParty':
				    	thirdPartyLogin(id); return action + " - called";
				    	break;
				    case 'anom':
				    	anomymousLogin(); return action + " - called";
				    	break;
				    default:
				        return action + " - failed";
				} 
			}
			// logout
			else if(action === 'logout'){
				$rootScope.auth.$unauth();
				return action + " - called";
			}
			// Change password
			else if(action === 'changePassword' && provider ==='password'){
				$rootScope.auth.$changePassword({
				  email: id,
				  oldPassword: password,
				  newPassword: changeParameter
				}).then(function() {
				  console.log("Password changed successfully!");
				}).catch(function(error) {
				  console.error("Error: ", error);
				});
			}
			// Change email
			else if(action ==='changeEmail' && provider ==='password'){
				$rootScope.auth.$changeEmail({
				  oldEmail: id,
				  newEmail: changeParamer,
				  password: password
				}).then(function() {
				  console.log("Email changed successfully!");
				}).catch(function(error) {
				  console.error("Error: ", error);
				});
			}

			//password reset
			else if(action ==='passwordReset' && provider ==='password'){
				$rootScope.auth.loginStatus = "trying";
				$rootScope.auth.$resetPassword({
				  email: id
				}).then(function() {
				  console.log("Password reset email sent successfully!");
				  $rootScope.auth.loginStatus = $rootScope.auth.alert = $rootScope.auth.alertMsg = "";
				  window.location.assign("/user/login");
				}).catch(function(error) {
				  console.error("Error: ", error);
				  $rootScope.auth.loginStatus = "";
				  $rootScope.auth.alert = "autherror";
				  $rootScope.auth.alertMsg = "Error ... perhaps you've entered an incorrect email?";
				});
			}

			// third party login function
			function thirdPartyLogin(id){
				$rootScope.auth.$authWithOAuthPopup(id).then(function(authData) {
				  console.log("Logged in");
				  $rootScope.auth.alertMsg = '';
				  $rootScope.auth.alert = '';
				}).catch(function(error) {
				  console.error("Authentication failed:", error);
				  $rootScope.auth.loginStatus = 'loggedOut';
				  $rootScope.auth.alert = 'autherror';
				  $rootScope.auth.alertMsg = error.message;
				  $rootScope.auth.alertMsg = "Error logging user in";
				});
			};

			// password login function
			function passwordLogin(email, password){
				$rootScope.auth.$authWithPassword({
				  email: id,
				  password: password
				}).then(function(authData) {
				  console.log("Logged in");
				  $rootScope.auth.alertMsg = '';
				  $rootScope.auth.alert = '';
				}).catch(function(error) {
				  //console.error("Authentication failed:", error);
				  $rootScope.auth.loginStatus = 'loggedOut';
				  $rootScope.auth.alert = 'autherror';
				  if (error) {
				    switch (error.code) {
				      case "INVALID_EMAIL":
				        $rootScope.auth.alertMsg = "The specified user account email is invalid.";
				        break;
				      case "INVALID_PASSWORD":
				        $rootScope.auth.alertMsg = "The specified user account password is incorrect.";
				        break;
				      case "INVALID_USER":
				        $rootScope.auth.alertMsg = "The specified user account does not exist.";
				        $rootScope.auth.alertType = "danger";
				        break;
				      default:
				        $rootScope.auth.alertMsg = "Error logging user in:";
				    };
				  }
				});
			};

			// anonymous login
			function anomymousLogin(){
				$rootScope.auth.$authAnonymously().then(function(authData) {
				  console.log("Logged in anonymously");
				  $rootScope.auth.alertMsg = '';
				  $rootScope.auth.alert = '';
				}).catch(function(error) {
				  console.error("Authentication failed:", error);
				  $rootScope.auth.loginStatus = 'loggedOut';
				  $rootScope.auth.alert = 'autherror';
				  $rootScope.auth.alertMsg = "Error logging user in";
				});
			}
		},
		get : function(authdata){
			return $firebaseObject(fbref.child('users/' + authdata.uid));
		}
	}
}]);
